Key

Enum Key 

pub enum Key {
    Bool(bool),
    N64(i64),
    U64(u64),
    F32(f32),
    F64(f64),
    Bytes(Vec<u8>),
    Text(String),
}
Possible types that can be used as a key in cbor-map.

Variants



Bool(bool)



N64(i64)



U64(u64)



F32(f32)



F64(f64)



Bytes(Vec<u8>)



Text(String)

Implementations

Source

impl Key

pub fn to_type_order(&self) -> usize

As per cbor spec, map’s key can be a heterogeneous collection of types. That is, some of the keys can be Boolean, other can be numbers etc ..

This function defines the ordering for supported key types. As,

  • Key::Bool, sort before every other keys.
  • Key::N64, sort after boolean type.
  • Key::U64, sort after negative integers.
  • Key::F32, sort after positive integers.
  • Key::F64, sort after 32-bit floating point numbers.
  • Key::Bytes, sort after 64-bit floating point numbers.
  • Key::Text, sort after bytes.